@@ -6,8 +6,9 @@ from itertools import groupby
 
 from sql import Null
 from sql.aggregate import Max, Sum
+from sql.conditionals import Case
 
-from trytond.model import Workflow, ModelView, ModelSQL, fields
+from trytond.model import Workflow, ModelView, ModelSQL, fields, Check
 from trytond.pyson import Eval, If, Bool
 from trytond.transaction import Transaction
 from trytond import backend
@@ -75,8 +76,7 @@ class Statement(Workflow, ModelSQL, ModelView):
         depends=['state', 'company'])
     currency_digits = fields.Function(fields.Integer('Currency Digits'),
         'on_change_with_currency_digits')
-    date = fields.Date('Date', required=True, states=_STATES, depends=_DEPENDS,
-        select=True)
+    date = fields.Date('Date', required=True, select=True)
     start_balance = fields.Numeric('Start Balance',
         digits=(16, Eval('currency_digits', 2)),
         states=_BALANCE_STATES, depends=_BALANCE_DEPENDS + ['currency_digits'])
@@ -558,15 +558,16 @@ class Line(ModelSQL, ModelView):
                 'amount_greater_invoice_amount_to_pay': ('Amount "%s" is '
                     'greater than the amount to pay of invoice.'),
                 })
+        t = cls.__table__()
         cls._sql_constraints += [
-            ('check_statement_line_amount', 'CHECK(amount != 0)',
+            ('check_statement_line_amount', Check(t, t.amount != 0),
                 'Amount should be a positive or negative value.'),
             ]
 
     @staticmethod
     def order_sequence(tables):
         table, _ = tables[None]
-        return [table.sequence == Null, table.sequence]
+        return [Case((table.sequence == Null, 0), else_=1), table.sequence]
 
     @staticmethod
     def default_amount():
